PyQtGraph’s Widgets — pyqtgraph 0.11.0rc0 documentation

# PyQtGraph’s Widgets

PyQtGraph provides several QWidget subclasses which are useful for building user interfaces. These widgets can generally be used in any Qt application and provide functionality that is frequently useful in science and engineering applications.

Contents:

- PlotWidget
- ImageView
- dockarea module
- SpinBox
- GradientWidget
- HistogramLUTWidget
- parametertree module
- ConsoleWidget
- ColorMapWidget
- ScatterPlotWidget
- GraphicsView
- DataTreeWidget
- TableWidget
- TreeWidget
- CheckTable
- ColorButton
- GraphicsLayoutWidget
- ProgressDialog
- FileDialog
- JoystickButton
- MultiPlotWidget
- VerticalLabel
- RemoteGraphicsView
- MatplotlibWidget
- FeedbackButton
- ComboBox
- LayoutWidget
- PathButton
- ValueLabel
- BusyCursor